Zooming using mouse wheel
~~~~~~~~~~~~~~~~~~~~~~~~~

``Ctrl+MouseWheel`` can be used to zoom in the plot windows.
Additionally, ``x+MouseWheel`` zooms only the x-axis and ``y+MouseWheel`` zooms only the y-axis.

The zoom focusses on the mouse pointer. With ``Ctrl``, the axes aspect ratio is kept; with ``x`` or ``y``, only the respective axis is scaled.

Zooming is currently only supported on rectilinear Axes.
